@@ -16,16 +16,13 @@
 #' array_extract(x, `2` = 2, `3` = 3)
 
 array_extract <- function(.arr, ..., default = "1") {
+  stopifnot(is.array(.arr))
+
   ls <- dotlist(...)
-
-  if (!is.array(.arr)) {
-    stop(".arr must be an array", call. = FALSE)
-  }
-
   nm <- wuffle(as.integer(names(ls) %||% seq_along(ls)))
 
   if (anyNA(nm)) {
-    stop("... must be fully named by integers or have no names", call. = FALSE)
+    stop(cond_arary_extract_names())
   }
 
   ds <- dim(.arr)
@@ -62,3 +59,13 @@ dotlist <- function(...) {
 
   list(...)
 }
+
+
+# conditions --------------------------------------------------------------
+
+cond_arary_extract_names <- function() {
+  new_condition(
+    "... must be fully named by integers or have no names",
+    "array_extract_names"
+  )
+}
