@@ -1,12 +1,13 @@
 #' mark
 #'
-#' Miscellaneous, Analytic R Code
+#' Miscellaneous, Analytic R Kernels
 #'
+#' @import fuj
 #' @docType package
 #' @name mark
 "_PACKAGE"
 
-op.mark <- list(
+op.mark <- list( # nolint: object_name_linter.
   mark.author            = NULL,
   # control for check_interactive() to return interactive() or TRUE
   mark.check_interactive = TRUE,
