@@ -17,7 +17,7 @@ row_bind <- function(...) {
   }
 
   if (!all(vap_lgl(ls, is.data.frame))) {
-    stop("... must only be data.frames", call. = FALSE)
+    stop(cond_row_bind_dataframes())
   }
 
   names <- lapply(ls, names)
@@ -34,7 +34,7 @@ row_bind <- function(...) {
       w <- which(is.na(b))
 
       if (length(w)) {
-        a <- quick_df(set_names0(insert(a, w, NA), all_names))
+        a <- quick_df(set_names(insert(a, w, NA), all_names))
       }
 
       a
@@ -57,5 +57,11 @@ rbind2 <- function(...) {
     res[[i]] <- Reduce(c, lapply(ls, `[[`, i))
   }
 
-  quick_df(set_names0(res, names(ls[[1]])))
+  quick_df(set_names(res, names(ls[[1]])))
+}
+
+# conditions --------------------------------------------------------------
+
+cond_row_bind_dataframes <- function() {
+  new_condition("... must only be data.frames", "row_bind_dataframes")
 }
