@@ -1,73 +1,23 @@
-#' @importFrom magrittr %>%
-magrittr::`%>%`
 
-# Like rlang::`%||%` but uses base is.null -- same thing
-
-#' Default value for NULL
-#'
-#' Replace if `NULL`
-#'
-#' @details
-#' A mostly copy of `rlang`'s `%||%` except does not use [rlang::is_null()],
-#'   which, currently, calls the same primitive `is.null` function as
-#'   [base::is.null()].
-#' This is not to be exported due to conflicts with `purrr`
-#'
-#' @param x,y If `x` is `NULL` returns `y`; otherwise `x`
-#'
-#' @name null_default
-#' @noRd
-`%||%` <- function(x, y) {
-  if (is.null(x)) y else x
-}
-`%len%` <- function(x, y) {
-  if (length(x)) x else y
-}
 which0 <- function(x) {
   which(x) %len% 0L
 }
 # isTRUE, isFALSE, ...
-isNA <- function(x) {
+isNA <- function(x) { # nolint: object_name_linter.
   is.logical(x) && length(x) == 1L && is.na(x)
 }
 
-#' Colons
-#'
-#' Get an object from a package
-#'
-#' @details
-#' This is a work around to calling `:::`.
-#'
-#' @section WARNING:
-#' To reiterate from other documentation: it is not advised to use `:::` in
-#'   your code as it will retrieve non-exported objects that may be more
-#'   likely to change in their functionality that exported objects.
-#'
-#' @param package Name of the package
-#' @param name Name to retrieve
-#' @return The variable `name` from package `package`
-#'
-#' @export
-`%colons%` <- function(package, name) {
-  tryCatch(
-    get(name, envir = asNamespace(package)),
-    error = function(e) {
-      stop(sprintf("`%s` not found in package `%s`",
-        name, package),
-        call. = FALSE)
-    }
-  )
-}
-
-# modified from https://github.com/tidyverse/purrr/blob/5aca9df41452f272fcef792dbc6d584be8be7167/R/utils.R
+# modified from https://github.com/tidyverse/purrr/blob/5aca9df41452f272fcef792dbc6d584be8be7167/R/utils.R # nolint: line_length_linter.
 use_color <- function() {
   rn("crayon") && crayon::has_color()
 }
 
-use_color <- function() { rn("crayon") && crayon::has_color() }
+# nolint start: brace_linter.
 crayon_blue  <- function(x) { if (use_color()) crayon::blue(x)  else x }
 crayon_green <- function(x) { if (use_color()) crayon::green(x) else x }
 crayon_cyan  <- function(x) { if (use_color()) crayon::cyan(x)  else x }
+# nolint end: brace_linter.
+
 #' Parse and evaluate text
 #'
 #' A wrapper for eval(parse(text = .))
@@ -97,7 +47,7 @@ print_no_attr <- function(x, ...) {
 #'
 #' @export
 #' @seealso [base::which()]
-that <- function(x, arr.ind = FALSE, useNames = TRUE) {
+that <- function(x, arr.ind = FALSE, useNames = TRUE) { # nolint: object_name_linter, line_length_linter.
   # TODO consider that() as #seq_along(x)[x]?
   which(x, arr.ind = arr.ind, useNames = useNames)
 }
@@ -142,9 +92,12 @@ is_atomic0 <- function(x) {
   is.atomic(x) && !is.null(x)
 }
 
+# nolint start: brace_linter.
 cat0 <- function(...) { cat(..., sep = "") }
 catln <- function(...) { cat(..., sep = "\n") }
 charexpr <- function(x) { as.character(as.expression(x)) }
+# nolint end: brace_linter.
+
 mark_temp <- function(ext = "") {
   if (!grepl("^[.]", ext) && !identical(ext, "") && !is.na(ext)) {
     ext <- paste0(".", ext)
@@ -161,11 +114,26 @@ mark_temp <- function(ext = "") {
 }
 
 check_is_vector <- function(x, mode = "any") {
-  if (isS4(x) | inherits(x, c("data.frame", "matrix", "array")) | !is.vector(remove_attributes(x), mode)) {
-    stop(deparse(substitute(x)), " must be a vector of mode ", mode, call. = FALSE)
+  if (
+    isS4(x) ||
+    inherits(x, c("data.frame", "matrix", "array")) ||
+    !is.vector(remove_attributes(x), mode)
+  ) {
+    x <- deparse1(substitute(x))
+    stop(cond_check_is_vector_mode(x, mode))
   }
+
+  invisible()
 }
 
+cond_check_is_vector_mode <- function(x, mode) {
+  new_condition(
+    paste(x, "must be a vector of mode", mode),
+    "check_is_vector_mode"
+  )
+}
+
+
 add_attributes <- function(x, ...) {
   attributes(x) <- c(attributes(x), list(...))
   x
@@ -210,7 +178,14 @@ check_interactive <- function() {
     return(FALSE)
   }
 
-  stop("mark.check_interactive must be TRUE, FALSE, or NA")
+  stop(cond_check_interactive())
+}
+
+cond_check_interactive <- function() {
+  new_condition(
+    "mark.check_interactive must be TRUE, FALSE, or NA",
+    "check_interactive"
+  )
 }
 
 try_formats <- function(date = FALSE) {
@@ -245,32 +220,19 @@ dupe_check <- function(x, n = getOption("mark.dupe.n", 5)) {
   dupes <- utils::head(dupes, n)
 
   if (n_dupes) {
-    stop(
-      "Duplicate values found in ", n_dupes, " location(s) :\n",
-      if (n_dupes > n) sprintf("(first %i)\n", n),
-      paste0("  > ", sprintf("[%s] %s", format(dupes), format(x[dupes])), "\n"),
-      if (n_dupes > n) "... and ", n_dupes - n, " more",
-      call. = FALSE
-    )
+    stop(cond_dupe_check(x, dupes, n_dupes, n))
   }
 
   invisible(NULL)
 }
 
-exattr <- function(x, which) {
-  attr(x, which = which, exact = TRUE)
-}
+cond_dupe_check <- function(x, dupes, n_dupes, n) {
+  msg <- paste0(
+    "Duplicate values found in ", n_dupes, " location(s) :\n",
+    if (n_dupes > n) sprintf("(first %i)\n", n),
+    paste0("  > ", sprintf("[%s] %s", format(dupes), format(x[dupes])), "\n"),
+    if (n_dupes > n) "... and ", n_dupes - n, " more"
+  )
 
-# operating systems -------------------------------------------------------
-
-is_windows <- function() {
-  Sys.info()[["sysname"]] == "Windows"
-}
-
-is_macos <- function() {
-  Sys.info()[["sysname"]] == "Darwin"
-}
-
-is_linux <- function() {
-  Sys.info()[["sysname"]] == "Linux"
+  new_condition(msg, "dupe_check")
 }
