@@ -16,9 +16,9 @@ test_that("array_extract() works", {
 
 test_that("array_extract() errors", {
   x <- array(1:9, dim = c(3, 3))
-  expect_error(array_extract(1), "must be an array")
+  expect_error(array_extract(1), class = "simpleError")
   expect_error(array_extract(x, 2, 3), NA)
-  expect_error(array_extract(x, a = 2, b = 3), "named by integers")
+  expect_error(array_extract(x, a = 2, b = 3), class = "arrayExtractNamesError")
 })
 
 test_that("dot_list() reurns correctly", {
