@@ -5,10 +5,10 @@ test_that("switch_params() works as expected", {
 
 test_that("switch_case() works as expected", {
   res <- switch_case(
-    1:5 == 4      ~ NA_integer_, # 4
-    1:5 %% 2 == 0 ~ 1:5,         # 2 & 4
-    1:5 == 1      ~ 6:10,        # 1
-    .default = -1L               # 3 & 5
+    1:5 == 4      ~ NA_integer_, #> 4
+    1:5 %% 2 == 0 ~ 1:5,         #> 2 & 4
+    1:5 == 1      ~ 6:10,        #> 1
+    .default = -1L               #> 3 & 5
   )
 
   expect_equal(res, c(6L, 2L, -1L, NA_integer_, -1L))
@@ -25,12 +25,12 @@ test_that("switch_case() works as expected", {
 test_that("switch_in_case() works as expected", {
   x <- c(1, 2, 12, 4, 20, 21)
   res <- switch_in_case(x, 1:10 ~ 1, 11:20 ~ 2)
-  exp <- set_names0(c(1, 1, 2, 1, 2, NA), x)
+  exp <- set_names(c(1, 1, 2, 1, 2, NA), x)
   expect_equal(res, exp)
 
   x <- c("a", "b", "d", "e", "g", "j")
   res <- switch_in_case(x, letters[1:3] ~ "a", letters[5:6] ~ "e")
-  exp <- set_names0(c("a", "a", NA, "e", NA, NA), x)
+  exp <- set_names(c("a", "a", NA, "e", NA, NA), x)
   expect_equal(res, exp)
 
   # handles functions
@@ -44,7 +44,7 @@ test_that("switch_in_case() handles evaluations", {
   use_these <- c(1, 3, 2, 5)
   x <- 1:6
   res <- switch_in_case(x, use_these ~ TRUE, .default = FALSE)
-  expect_equal(res, set_names0(x %in% use_these, x))
+  expect_equal(res, set_names(x %in% use_these, x))
 
   x <- seq.int(1, 60, 6)
   res <- switch_in_case(
@@ -54,7 +54,7 @@ test_that("switch_in_case() handles evaluations", {
     c(22, 24, 26) ~ "c",
     30:Inf ~ "d"
   )
-  exp_res <- set_names0(c("a", "a", "b", "b", NA, "d", "d", "d", "d", "d"), x)
+  exp_res <- set_names(c("a", "a", "b", "b", NA, "d", "d", "d", "d", "d"), x)
   expect_equal(res, exp_res)
 
   ne <- new.env()
